##  Insights from Objective Fact Sheet
Answer the following questions with reports based on the objective fact sheet:
  * What are the organization’s objectives?
  * Which business unit is accountable for achieving an objective?
  * Which business capabilities are critical to achieving organizational objectives?
  * Which initiatives contribute to achieving an objective, and what is the impact on the IT landscape over time?
